summaryrefslogtreecommitdiff
path: root/edge/mocks
diff options
context:
space:
mode:
authorlvchenggang <lvchenggang_yewu@cmss.chinamobile.com>2020-11-18 17:25:35 +0800
committerlvchenggang <lvchenggang@cmss.chinamobile.com>2020-11-20 10:26:26 +0800
commit6c9f85bdb31156d707135a529eaf86cd68409214 (patch)
tree3aa2766a8cca36c115d62bc0cd117151acb793c3 /edge/mocks
parentmetamanager remote query timeout configurable (diff)
downloadkubeedge-6c9f85bdb31156d707135a529eaf86cd68409214.tar.gz
fix grammar of method in edgehub
Diffstat (limited to 'edge/mocks')
-rw-r--r--edge/mocks/edgehub/fake_adapter.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/edge/mocks/edgehub/fake_adapter.go b/edge/mocks/edgehub/fake_adapter.go
index d5e511d08..d76f55217 100644
--- a/edge/mocks/edgehub/fake_adapter.go
+++ b/edge/mocks/edgehub/fake_adapter.go
@@ -81,12 +81,12 @@ func (mr *MockAdapterMockRecorder) Send(arg0 interface{}) *gomock.Call {
return mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "Send", reflect.TypeOf((*MockAdapter)(nil).Send), arg0)
}
-// Uninit mocks base method
-func (m *MockAdapter) Uninit() {
- m.ctrl.Call(m, "Uninit")
+// UnInit mocks base method
+func (m *MockAdapter) UnInit() {
+ m.ctrl.Call(m, "UnInit")
}
-// Uninit indicates an expected call of Uninit
-func (mr *MockAdapterMockRecorder) Uninit() *gomock.Call {
- return mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "Uninit", reflect.TypeOf((*MockAdapter)(nil).Uninit))
+// UnInit indicates an expected call of UnInit
+func (mr *MockAdapterMockRecorder) UnInit() *gomock.Call {
+ return mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UnInit", reflect.TypeOf((*MockAdapter)(nil).UnInit))
}